@@ -215,30 +215,27 @@ class FoundryProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
 
         # Verify is actually a Foundry provider,
         # or else skip it to possibly try another port.
-        # TODO: Once we are on web3.py 0.6.0b8 or later, can just use snake_case here.
-        client_version = getattr(self._web3, "client_version", getattr(self._web3, "clientVersion"))
-
-        if "anvil" in client_version.lower():
+        client_version = self._web3.client_version.lower()
+        if "anvil" in client_version:
             self._web3.eth.set_gas_price_strategy(rpc_gas_price_strategy)
         else:
             raise ProviderError(
                 f"Port '{self.port}' already in use by another process that isn't an Anvil node."
             )
 
-        self._set_poa_middleware()
+        def check_poa(block_id) -> bool:
+            try:
+                block = self.web3.eth.get_block(block_id)
+            except ExtraDataLengthError:
+                return True
+            else:
+                return (
+                    "proofOfAuthorityData" in block
+                    or len(block.get("extraData", "")) > MAX_EXTRADATA_LENGTH
+                )
 
-    def _set_poa_middleware(self):
-        try:
-            block = self.web3.eth.get_block(0)
-        except ExtraDataLengthError:
-            began_poa = True
-        else:
-            began_poa = (
-                "proofOfAuthorityData" in block
-                or len(block.get("extraData", "")) > MAX_EXTRADATA_LENGTH
-            )
-
-        if began_poa:
+        # Handle if using PoA
+        if any(map(check_poa, (0, "latest"))):
             self._web3.middleware_onion.inject(geth_poa_middleware, layer=0)
 
     def _start(self):
